@@ -2,7 +2,8 @@ use std::path::{Path, PathBuf};
 
 use anyhow::{Context, Result};
 use ast_grep_config::{
-  from_yaml_string, CombinedScan, PreScan, RuleCollection, RuleConfig, Severity,
+  from_yaml_string, CombinedScan, PreScan, RuleCollection, RuleConfig, SerializableRule,
+  SerializableRuleConfig, SerializableRuleCore, Severity,
 };
 use ast_grep_core::{NodeMatch, StrDoc};
 use clap::Args;
@@ -17,7 +18,7 @@ use crate::print::{
 };
 use crate::utils::ErrorContext as EC;
 use crate::utils::{filter_file_interactive, InputArgs, OutputArgs};
-use crate::utils::{FileStats, RuleStats, ScanStats};
+use crate::utils::{FileTrace, RuleTrace, ScanTrace};
 use crate::utils::{Items, PathWorker, StdInWorker, Worker};
 
 type AstGrep = ast_grep_core::AstGrep<StrDoc<SgLang>>;
@@ -102,11 +103,11 @@ struct ScanWithConfig<Printer> {
   arg: ScanArg,
   printer: Printer,
   configs: RuleCollection<SgLang>,
-  stats: ScanStats,
+  trace: ScanTrace,
 }
 impl<P: Printer> ScanWithConfig<P> {
   fn try_new(mut arg: ScanArg, printer: P) -> Result<Self> {
-    let mut rule_stats = RuleStats::default();
+    let mut rule_trace = RuleTrace::default();
     let configs = if let Some(path) = &arg.rule {
       let rules = read_rule_file(path, None)?;
       RuleCollection::try_new(rules).context(EC::GlobPattern)?
@@ -116,15 +117,15 @@ impl<P: Printer> ScanWithConfig<P> {
       RuleCollection::try_new(rules).context(EC::GlobPattern)?
     } else {
       let (configs, r_stats) = find_rules(arg.config.take(), arg.filter.as_ref())?;
-      rule_stats = r_stats;
+      rule_trace = r_stats;
       configs
     };
-    let stats = arg.output.tracing.scan_stats(rule_stats);
+    let trace = arg.output.tracing.scan_trace(rule_trace);
     Ok(Self {
       arg,
       printer,
       configs,
-      stats,
+      trace,
     })
   }
 }
@@ -159,10 +160,16 @@ impl<P: Printer> Worker for ScanWithConfig<P> {
         }
         match_rule_on_file(path, matches, rule, &file_content, &self.printer)?;
       }
+      print_unused_suppressions(
+        path,
+        scanned.unused_suppressions,
+        &file_content,
+        &self.printer,
+      )?;
     }
     self.printer.after_print()?;
-    if let Some(stats) = self.stats.print(self.arg.output.json.is_some()) {
-      eprintln!("{}", stats);
+    if let Some(trace) = self.trace.print(self.arg.output.json.is_some()) {
+      eprintln!("{}", trace);
     }
     if error_count > 0 {
       Err(anyhow::anyhow!(EC::DiagnosticError(error_count)))
@@ -172,9 +179,40 @@ impl<P: Printer> Worker for ScanWithConfig<P> {
   }
 }
 
+fn print_unused_suppressions(
+  path: &Path,
+  matches: Vec<NodeMatch<StrDoc<SgLang>>>,
+  file_content: &String,
+  printer: &impl Printer,
+) -> Result<()> {
+  let rule: SerializableRule = serde_json::from_str(r#"{"pattern": "a"}"#).unwrap();
+  let core = SerializableRuleCore {
+    rule,
+    constraints: None,
+    fix: None,
+    transform: None,
+    utils: None,
+  };
+  let config = SerializableRuleConfig::<SgLang> {
+    core,
+    id: "unused-suppression".to_string(),
+    files: None,
+    ignores: None,
+    language: "rust".parse().unwrap(),
+    message: "Unused '@ast-grep-ignore' directive.".into(),
+    metadata: None,
+    note: None,
+    rewriters: None,
+    severity: Severity::Hint,
+    url: None,
+  };
+  let rule_config = RuleConfig::try_from(config, &Default::default()).unwrap();
+  match_rule_on_file(path, matches, &rule_config, file_content, printer)
+}
+
 impl<P: Printer> PathWorker for ScanWithConfig<P> {
-  fn get_stats(&self) -> &FileStats {
-    &self.stats.file_stats
+  fn get_trace(&self) -> &FileTrace {
+    &self.trace.file_trace
   }
   fn build_walk(&self) -> Result<WalkParallel> {
     self.arg.input.walk()
@@ -324,6 +362,7 @@ rule:
         stdin: false,
         follow: false,
         globs: vec![],
+        threads: 0,
       },
       output: OutputArgs {
         interactive: false,
